## Product details

Aveeno Baby Welcome Little One Gift Basket with five skin care essentials specially formulated for baby's delicate skin & hair. For parents & parents-to-be, this baby gift set is a perfect gift for a baby shower & includes baby wash & shampoo, calming bath wash, cleansing wipes, daily moisture lotion, & baby balm. Daily Moisture Wash & Shampoo has a tear-free, hypoallergenic, formula that cleanses baby's hair & skin without drying, making it gentle enough for sensitive skin. Calming Comfort Bath & Wash has soothing scents of lavender & vanilla to help calm & relax baby before bedtime so they can experience a more restful sleep when combined with a warm bath. Daily Moisture Body lotion is formulated with nourishing prebiotic oat to keep your baby's skin moisturized for 24 hours. All Over Wipes with aloe & oat extract gently cleans & leaves baby's face, bottom, hands & body feeling moisturized. Healthy Start Balm leaves a nourishing layer to help moisturize baby's developing skin.
Baby skin care gift set contains five Aveeno Baby skin care essentials for babies' delicate skin
Baby gift set from a dermatologist & pediatrician-recommended brand makes a perfect baby shower gift
All nourishing baby products are gentle, hypoallergenic, & leave baby's skin feeling moisturized
Daily Moisture Wash & Shampoo with a tear-free formula cleanses baby's hair & skin without drying
Calming Comfort Bath & Body Wash with scents of lavender & vanilla helps relax baby before bed
All Over Wipes to help wipe away dirt & germs contain aloe & oat extract to nourish baby's skin
Daily Moisture Lotion with nourishing prebiotic oat moisturizes baby's delicate skin for 24-hours
Healthy Start Newborn Baby Balm leaves a nourishing layer to help moisturize baby's developing skin
info:
We aim to show you accurate product information. Manufacturers, suppliers and others provide what you see here, and we have not verified it.  See our disclaimer
## Specifications

Age group
Newborn, Infant, Toddler
Retail packaging
Gift Set
Piece count
5
Scent
lavender & vanilla
More details
## Directions

Instructions
AVEENO Baby Daily Moisture Lotion 8 oz (227g): Apply as needed. AVEENO Baby Daily Moisture Healthy Start Newborn Balm 0.5 fl oz (14 g): With clean hands, gently apply on baby's skin two times a day, morning and evening, for proactive newborn moisturization. AVEENO Baby Sensitive All Over Wipes (64 ct): Open lid and remove inner seal upon first use. Close lid firmly after every use to keep moist. AVEENO Baby Daily Moisture Wash & Shampoo 8 fl oz (236 mL): Dispense onto a wet washcloth or hand and apply to hair and body. Lather and rinse. AVEENO Baby CALMING COMFORT Bath 8 fl oz (236 mL): Dispense directly into bath water. Or dispense onto a wet washcloth or hand and apply to hair and body. Lather and rinse.
Fabric Care Instructions
No fabric associated with giftset
## Warranty

Warranty information
Please be aware that the warranty terms on items offered for sale by third party Marketplace sellers may differ from those displayed in this section (if any). To confirm warranty terms on an item offered for sale by a third party Marketplace seller, please use the 'Contact seller' feature on the third party Marketplace seller's information page and request the item's warranty terms prior to purchase.
